@@ -15,10 +15,6 @@
         <source>Translations</source>
         <translation>Übersetzungen</translation>
     </message>
-    <message>
-        <source>Packages</source>
-        <translation type="vanished">Pakete</translation>
-    </message>
     <message>
         <source>About</source>
         <translation>Über</translation>
@@ -1101,10 +1097,6 @@ Do you want to overwrite?</source>
         <source>Palettes</source>
         <translation>Paletten</translation>
     </message>
-    <message>
-        <source>Highlighting mode</source>
-        <translation type="vanished">Hervorhebungsmodus</translation>
-    </message>
     <message>
         <source>Profiles</source>
         <translation></translation>
@@ -1823,13 +1815,17 @@ To use time-based reminders, specify the time signature in 24-hour format [hh:mm
         <source>Show ebooks fine</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Show tabs and spaces</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Subtitles: shift timecodes by msecs</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>CTioReadOnly</name>
-    <message>
-        <source>saving of this format is not supported</source>
-        <translation type="vanished">Das Speichern dieses Formats wird nicht unterstützt</translation>
-    </message>
     <message>
         <source>Saving for this format is not supported</source>
         <translation></translation>
@@ -1842,13 +1838,6 @@ To use time-based reminders, specify the time signature in 24-hour format [hh:mm
         <translation></translation>
     </message>
 </context>
-<context>
-    <name>CViewerWindow</name>
-    <message>
-        <source>preview</source>
-        <translation type="obsolete">Vorschau</translation>
-    </message>
-</context>
 <context>
     <name>CZORWindow</name>
     <message>
@@ -1883,499 +1872,4 @@ To use time-based reminders, specify the time signature in 24-hour format [hh:mm
         <translation></translation>
     </message>
 </context>
-<context>
-    <name>tea</name>
-    <message>
-        <source>Charset</source>
-        <translation type="vanished">Zeichensatz</translation>
-    </message>
-    <message>
-        <source>New</source>
-        <translation type="vanished">Neu</translation>
-    </message>
-    <message>
-        <source>Create a new file</source>
-        <translation type="vanished">Neue Datei erstellen</translation>
-    </message>
-    <message>
-        <source>Open file</source>
-        <translation type="vanished">Datei öffnen</translation>
-    </message>
-    <message>
-        <source>Save</source>
-        <translation type="vanished">Speichern</translation>
-    </message>
-    <message>
-        <source>Save As</source>
-        <translation type="vanished">Speichern unter</translation>
-    </message>
-    <message>
-        <source>Exit</source>
-        <translation type="vanished">Beenden</translation>
-    </message>
-    <message>
-        <source>Exit the application</source>
-        <translation type="vanished">Beenden der Applikation</translation>
-    </message>
-    <message>
-        <source>Cut</source>
-        <translation type="vanished">Ausschneiden</translation>
-    </message>
-    <message>
-        <source>Copy</source>
-        <translation type="vanished">Kopieren</translation>
-    </message>
-    <message>
-        <source>Paste</source>
-        <translation type="vanished">Einfügen</translation>
-    </message>
-    <message>
-        <source>Undo</source>
-        <translation type="vanished">Rückgängig</translation>
-    </message>
-    <message>
-        <source>Redo</source>
-        <translation type="vanished">Wiederholen</translation>
-    </message>
-    <message>
-        <source>About</source>
-        <translation type="vanished">Über</translation>
-    </message>
-    <message>
-        <source>About Qt</source>
-        <translation type="vanished">Über Qt</translation>
-    </message>
-    <message>
-        <source>File</source>
-        <translation type="vanished">Datei</translation>
-    </message>
-    <message>
-        <source>Open</source>
-        <translation type="vanished">Öffnen</translation>
-    </message>
-    <message>
-        <source>Last closed file</source>
-        <translation type="vanished">Zuletzt geschlossene Datei</translation>
-    </message>
-    <message>
-        <source>Open at cursor</source>
-        <translation type="vanished">An Cursorposition öffnen</translation>
-    </message>
-    <message>
-        <source>Crapbook</source>
-        <translation type="vanished">Notizbuch</translation>
-    </message>
-    <message>
-        <source>Reload</source>
-        <translation type="vanished">Neu laden</translation>
-    </message>
-    <message>
-        <source>Recent files</source>
-        <translation type="vanished">Zuletzt geöffnete Dateien</translation>
-    </message>
-    <message>
-        <source>Bookmarks</source>
-        <translation type="vanished">Lesezeichen</translation>
-    </message>
-    <message>
-        <source>Edit bookmarks</source>
-        <translation type="vanished">Lesezeichen bearbeiten</translation>
-    </message>
-    <message>
-        <source>Add to bookmarks</source>
-        <translation type="vanished">Zu den Lesezeichen hinzufügen</translation>
-    </message>
-    <message>
-        <source>Templates</source>
-        <translation type="vanished">Vorlagen</translation>
-    </message>
-    <message>
-        <source>Sessions</source>
-        <translation type="vanished">Sitzungen</translation>
-    </message>
-    <message>
-        <source>Bookmarks list</source>
-        <translation type="vanished">Liste der Lesezeichen</translation>
-    </message>
-    <message>
-        <source>Programs list</source>
-        <translation type="vanished">Liste der Programme</translation>
-    </message>
-    <message>
-        <source>Print</source>
-        <translation type="vanished">Drucken</translation>
-    </message>
-    <message>
-        <source>Close current</source>
-        <translation type="vanished">Aktuelle Datei schließen</translation>
-    </message>
-    <message>
-        <source>Edit</source>
-        <translation type="vanished">Bearbeiten</translation>
-    </message>
-    <message>
-        <source>Copy current file name</source>
-        <translation type="vanished">Aktuellen Dateinamen kopieren</translation>
-    </message>
-    <message>
-        <source>Indent (tab)</source>
-        <translation type="vanished">Einrücken (Tab)</translation>
-    </message>
-    <message>
-        <source>Markup</source>
-        <translation type="vanished">Textauszeichnung</translation>
-    </message>
-    <message>
-        <source>Mode</source>
-        <translation type="vanished">Modus</translation>
-    </message>
-    <message>
-        <source>Header</source>
-        <translation type="vanished">Kopfzeilen</translation>
-    </message>
-    <message>
-        <source>Align</source>
-        <translation type="vanished">Ausrichtung</translation>
-    </message>
-    <message>
-        <source>Bold</source>
-        <translation type="vanished">Fett</translation>
-    </message>
-    <message>
-        <source>Italic</source>
-        <translation type="vanished">Kursiv</translation>
-    </message>
-    <message>
-        <source>Underline</source>
-        <translation type="vanished">Unterstrichen</translation>
-    </message>
-    <message>
-        <source>Link</source>
-        <translation type="vanished">Link</translation>
-    </message>
-    <message>
-        <source>Paragraph</source>
-        <translation type="vanished">Absatz</translation>
-    </message>
-    <message>
-        <source>Color</source>
-        <translation type="vanished">Farbe</translation>
-    </message>
-    <message>
-        <source>Non-breaking space</source>
-        <translation type="vanished">Geschütztes Leerzeichen</translation>
-    </message>
-    <message>
-        <source>Insert image</source>
-        <translation type="vanished">Bild einfügen</translation>
-    </message>
-    <message>
-        <source>[X]HTML tools</source>
-        <translation type="vanished">[X]HTML-Werkzeuge</translation>
-    </message>
-    <message>
-        <source>Convert tags to entities</source>
-        <translation type="vanished">Konvertiere Tags zu HTML-Code</translation>
-    </message>
-    <message>
-        <source>Antispam e-mail</source>
-        <translation type="vanished">Antispam E-Mail</translation>
-    </message>
-    <message>
-        <source>Document weight</source>
-        <translation type="vanished">Speicherplatz anzeigen</translation>
-    </message>
-    <message>
-        <source>Search</source>
-        <translation type="vanished">Suche</translation>
-    </message>
-    <message>
-        <source>Find</source>
-        <translation type="vanished">Suchen</translation>
-    </message>
-    <message>
-        <source>Find next</source>
-        <translation type="vanished">Vorwärts suchen</translation>
-    </message>
-    <message>
-        <source>Find previous</source>
-        <translation type="vanished">Rückwärts suchen</translation>
-    </message>
-    <message>
-        <source>Replace with</source>
-        <translation type="vanished">Ersetzen durch</translation>
-    </message>
-    <message>
-        <source>Replace all</source>
-        <translation type="vanished">Alles ersetzen</translation>
-    </message>
-    <message>
-        <source>Functions</source>
-        <translation type="vanished">Funktionen</translation>
-    </message>
-    <message>
-        <source>Snippets</source>
-        <translation type="vanished">Code-Schnipsel</translation>
-    </message>
-    <message>
-        <source>Scripts</source>
-        <translation type="vanished">Skripte</translation>
-    </message>
-    <message>
-        <source>Tables</source>
-        <translation type="vanished">Tabellen</translation>
-    </message>
-    <message>
-        <source>Date</source>
-        <translation type="vanished">Datum</translation>
-    </message>
-    <message>
-        <source>Time</source>
-        <translation type="vanished">Zeit</translation>
-    </message>
-    <message>
-        <source>Case</source>
-        <translation type="vanished">Groß-/Kleinschreibung</translation>
-    </message>
-    <message>
-        <source>UPCASE</source>
-        <translation type="vanished">GROSS-SCHREIBUNG</translation>
-    </message>
-    <message>
-        <source>lower case</source>
-        <translation type="vanished">kleinschreibung</translation>
-    </message>
-    <message>
-        <source>Sort</source>
-        <translation type="vanished">Sortieren</translation>
-    </message>
-    <message>
-        <source>Filter</source>
-        <translation type="vanished">Filter</translation>
-    </message>
-    <message>
-        <source>Remove duplicates</source>
-        <translation type="vanished">Dubletten entfernen</translation>
-    </message>
-    <message>
-        <source>Decimal to binary</source>
-        <translation type="vanished">Dezimal nach binär</translation>
-    </message>
-    <message>
-        <source>Binary to decimal</source>
-        <translation type="vanished">Binär nach dezimal</translation>
-    </message>
-    <message>
-        <source>Morse code</source>
-        <translation type="vanished">Morsecode</translation>
-    </message>
-    <message>
-        <source>From Russian to Morse</source>
-        <translation type="vanished">Russisch nach Morsecode</translation>
-    </message>
-    <message>
-        <source>From Morse To Russian</source>
-        <translation type="vanished">Morsecode nach Russisch</translation>
-    </message>
-    <message>
-        <source>From English to Morse</source>
-        <translation type="vanished">Englisch nach Morsecode</translation>
-    </message>
-    <message>
-        <source>From Morse To English</source>
-        <translation type="vanished">Morsecode nach Englisch</translation>
-    </message>
-    <message>
-        <source>Extract words</source>
-        <translation type="vanished">Wörter extrahieren</translation>
-    </message>
-    <message>
-        <source>Reverse</source>
-        <translation type="vanished">Umkehren</translation>
-    </message>
-    <message>
-        <source>Spell-checker languages</source>
-        <translation type="vanished">Sprachen für Rechtschreibprüfung</translation>
-    </message>
-    <message>
-        <source>Spell check</source>
-        <translation type="vanished">Rechtschreibprüfung</translation>
-    </message>
-    <message>
-        <source>Suggest</source>
-        <translation type="vanished">Vorschlagen</translation>
-    </message>
-    <message>
-        <source>Add to dictionary</source>
-        <translation type="vanished">Zum Wörterbuch hinzufügen</translation>
-    </message>
-    <message>
-        <source>Remove from dictionary</source>
-        <translation type="vanished">Aus dem Wörterbuch entfernen</translation>
-    </message>
-    <message>
-        <source>Run</source>
-        <translation type="vanished">Ausführen</translation>
-    </message>
-    <message>
-        <source>Nav</source>
-        <translation type="obsolete">Nav</translation>
-    </message>
-    <message>
-        <source>Save position</source>
-        <translation type="vanished">Speichere Position</translation>
-    </message>
-    <message>
-        <source>Go to saved position</source>
-        <translation type="vanished">Gehe zu gespeicherter Position</translation>
-    </message>
-    <message>
-        <source>Go to line</source>
-        <translation type="vanished">Gehe zu Zeile</translation>
-    </message>
-    <message>
-        <source>Rename</source>
-        <translation type="vanished">Umbenennen</translation>
-    </message>
-    <message>
-        <source>Delete file</source>
-        <translation type="vanished">Datei löschen</translation>
-    </message>
-    <message>
-        <source>File information</source>
-        <translation type="vanished">Dateiinformationen</translation>
-    </message>
-    <message>
-        <source>View</source>
-        <translation type="vanished">Ansicht</translation>
-    </message>
-    <message>
-        <source>Palettes</source>
-        <translation type="vanished">Paletten</translation>
-    </message>
-    <message>
-        <source>Highlighting mode</source>
-        <translation type="obsolete">Hervorhebungsmodus</translation>
-    </message>
-    <message>
-        <source>Hide error marks</source>
-        <translation type="vanished">Fehlermarkierungen verstecken</translation>
-    </message>
-    <message>
-        <source>Help</source>
-        <translation type="obsolete">Hilfe</translation>
-    </message>
-    <message>
-        <source>NEWS</source>
-        <translation type="vanished">NEUIGKEITEN</translation>
-    </message>
-    <message>
-        <source>License</source>
-        <translation type="vanished">Lizenz</translation>
-    </message>
-    <message>
-        <source>Ready</source>
-        <translation type="vanished">Fertig</translation>
-    </message>
-    <message>
-        <source>%1 is saved</source>
-        <translation type="vanished">%1 wurde gespeichert</translation>
-    </message>
-    <message>
-        <source>Editor font</source>
-        <translation type="vanished">Schriftart für Editor</translation>
-    </message>
-    <message>
-        <source>Word wrap</source>
-        <translation type="vanished">Zeilenumbruch</translation>
-    </message>
-    <message>
-        <source>Highlight current line</source>
-        <translation type="vanished">Aktuelle Zeile hervorheben</translation>
-    </message>
-    <message>
-        <source>Highlight paired brackets</source>
-        <translation type="vanished">Gepaarte Klammern hervorheben</translation>
-    </message>
-    <message>
-        <source>Automatic indent</source>
-        <translation type="vanished">Automatisches Einrücken</translation>
-    </message>
-    <message>
-        <source>Use spaces instead of tabs</source>
-        <translation type="vanished">Leerzeichen statt Tabulatoren verwenden</translation>
-    </message>
-    <message>
-        <source>Show cursor position</source>
-        <translation type="vanished">Anzeige der Cursorposition</translation>
-    </message>
-    <message>
-        <source>Tab width in spaces</source>
-        <translation type="vanished">Tabulatorbreite in Leerzeichen</translation>
-    </message>
-    <message>
-        <source>Interface</source>
-        <translation type="obsolete">Benutzeroberfläche</translation>
-    </message>
-    <message>
-        <source>Date format</source>
-        <translation type="vanished">Datumsformat</translation>
-    </message>
-    <message>
-        <source>Time format</source>
-        <translation type="vanished">Zeitformat</translation>
-    </message>
-    <message>
-        <source>Spell checker engine</source>
-        <translation type="vanished">Programm für Rechtschreibprüfung</translation>
-    </message>
-    <message>
-        <source>Hunspell dictionaries directory</source>
-        <translation type="vanished">Verzeichnis der Hunspell-Wörterbücher</translation>
-    </message>
-    <message>
-        <source>Select</source>
-        <translation type="vanished">Auswählen</translation>
-    </message>
-    <message>
-        <source>Assign</source>
-        <translation type="vanished">Zuweisen</translation>
-    </message>
-    <message>
-        <source>Remove</source>
-        <translation type="vanished">Entfernen</translation>
-    </message>
-    <message>
-        <source>Keyboard</source>
-        <translation type="vanished">Tastatur</translation>
-    </message>
-    <message>
-        <source>%p% completed</source>
-        <translation type="vanished">%p% fertig</translation>
-    </message>
-    <message>
-        <source>%1 - saved</source>
-        <translation type="vanished">%1 - gespeichert</translation>
-    </message>
-    <message>
-        <source>Cannot save %1</source>
-        <translation type="vanished">%1 konnte nicht gespeichert werden</translation>
-    </message>
-    <message>
-        <source>Name:</source>
-        <translation type="vanished">Name:</translation>
-    </message>
-    <message>
-        <source>Name</source>
-        <translation type="vanished">Name</translation>
-    </message>
-    <message>
-        <source>Save as</source>
-        <translation type="vanished">Speichern unter</translation>
-    </message>
-    <message>
-        <source>&lt;b&gt;Bookmarks&lt;/b&gt;</source>
-        <translation type="vanished">&lt;b&gt;Lesezeichen&lt;/b&gt;</translation>
-    </message>
-</context>
 </TS>
